<?php
/**
 * Load all active Clips.
 * 
 * @package WP_Clips_Multisite/Includes
 * @subpackage Loader
 */


class WP_Clips_Loader {


	public function __construct() {

		add_action( 'after_setup_theme', [ $this, 'clips_load' ], 5 );
	}

	/**
	 * Load all active Clips
	 * @since 3.0
	 */

	// Load after theme
	public function clips_load() {

		$id = is_network_admin() ? 0 : get_current_blog_id();

		// Include core Clip functions (incl network)
		$file = WP_CLIPS_NETW . '/clip-core/core-functions.php';
		if( file_exists( $file ) ) include( $file );

		foreach( [ WP_CLIPS_NETW, WP_CLIPS_SITE . $id ] as $dir ) {

			// Load admin Clips (if any)
			if( is_admin() )
				foreach( glob( $dir . '/precoded/clip-*/admin-functions.php', GLOB_NOSORT ) as $file ) {
					if( file_exists( $file ) ) include( $file );
				}

			// Load precoded Clips (if any)
			foreach( glob( $dir . '/precoded/clip-*/clip-functions.php', GLOB_NOSORT ) as $file ) {
				if( file_exists( $file ) ) include( $file );
			}
		}

		// Load custom functions (if active)
		$file = WP_CLIPS_SITE . $id . '/clip-custom/custom-functions.php';
		if( ! file_exists( $file ) ) return;

		include( $file );		

		// Enqueue custom script and stylesheet (if exists)
		add_action( 'wp_enqueue_scripts', function() use( $id ) {

			$file = 'site-' . $id . '/clip-custom/custom-script.js';
			if( file_exists( WP_CLIPS_DIR . $file ) )
				wp_enqueue_script( 'clip-custom-script-' . $id, content_url( 'clips/' . $file ),
									[ 'jquery' ], WP_CLIPS_VERS, true
					);

			$file = 'site-' . $id . '/clip-custom/custom-style.css';
			if( file_exists( WP_CLIPS_DIR . $file ) )
				wp_enqueue_style(  'clip-custom-style-' . $id, content_url( 'clips/' . $file ),
									[], WP_CLIPS_VERS
					);
		}, 15 );
	}	
}

new WP_Clips_Loader();